@@ -30,7 +30,7 @@ class Bedwars:
     def __init__(self, data):
         self.name = "Bedwars"
         self.prestige = Prestige(data.get("player", {}).get("achievements", {}).get("bedwars_level", 0))
-        self.coins = data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("coins_bedwars", 0)
+        self.coins = data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("coins", 0)
         self.games_played = data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("games_played_bedwars", 0)
         self.beds = BedsBrokenLost(
             data.get("player", {}).get("stats", {}).get("Bedwars", {}).get("beds_broken_bedwars", 0),
